from django.db import models

# Create your models here.
class SlideImage(models.Model):
    image = models.ImageField(upload_to='slides/')
    title = models.CharField(max_length=200)
    description = models.TextField()
    def __str__(self):
        return self.title

class Categories(models.Model):
    name = models.CharField(max_length=50)
    image = models.ImageField(upload_to='categories')
    added_at = models.DateTimeField(auto_now_add=True)

    def __str__(self):
        return self.name
class Products(models.Model):
    category = models.ForeignKey(Categories, on_delete=models.CASCADE)
    product_name = models.CharField(max_length=100)
    image = models.ImageField(upload_to='products')
    price = models.DecimalField(max_digits=65, decimal_places=0)
    description = models.TextField()
    discount_amount = models.DecimalField(max_digits=50, decimal_places=0, blank=True, null=True)
    discount_percent = models.DecimalField(max_digits=5, decimal_places=1, blank=True, null=True)
    added_at = models.DateTimeField(auto_now_add=True)
    bestseller = models.BooleanField(default=False)  # Add this line
    hotkit = models.BooleanField(default=False)  # Add this line
    bestliquid = models.BooleanField(default=False)  # Add this line
    hotsellingtool = models.BooleanField(default=False)  # Add this line

class ProductImage(models.Model):
    product = models.ForeignKey(Products, default=None, on_delete=models.CASCADE,blank=True, null=True)
    image = models.ImageField(upload_to='product_other_images/')  

    def __str__(self):
        return self.product.product_name

class CartItem(models.Model):
    product = models.ForeignKey(Products, on_delete=models.CASCADE)
    quantity = models.PositiveIntegerField(default=1)
    session_key = models.CharField(max_length=400, blank=True, null=True)
    # No user field for anonymous cart

class Order(models.Model):
    first_name = models.CharField(max_length=100)
    last_name = models.CharField(max_length=100)
    email = models.EmailField()
    phone = models.CharField(max_length=20)
    address = models.CharField(max_length=255)
    city = models.CharField(max_length=100)
    country = models.CharField(max_length=100)
    created_at = models.DateTimeField(auto_now_add=True)
    total_price = models.IntegerField(default=1)

class OrderItem(models.Model):
    order = models.ForeignKey(Order, related_name='items', on_delete=models.CASCADE)
    product = models.ForeignKey(Products, on_delete=models.CASCADE)
    quantity = models.PositiveIntegerField()
    image = models.ImageField(upload_to='orders/', default='') 
    price = models.IntegerField(default=1)


class BuyNow2(models.Model):
    name = models.CharField(max_length=255)
    phone_number = models.CharField(max_length=20)
    product_name = models.CharField(max_length=255)
    product_price = models.DecimalField(max_digits=10, decimal_places=2, default='')
    product_id = models.CharField(max_length=255)
    product_category = models.CharField(max_length=255, default='')
    created_at = models.DateTimeField(auto_now_add=True,blank=True, null=True)

    def __str__(self):
        return f"{self.name}'s Order for {self.product_name}"
    
class Currency(models.Model):
    name = models.CharField(max_length=50)
    code = models.CharField(max_length=3, unique=True)
    exchange_rate = models.DecimalField(max_digits=10, decimal_places=4, default=1.0)

    def __str__(self):
        return self.name
    
class WishlistItem(models.Model):
    session_key = models.CharField(max_length=100)
    product = models.ForeignKey(Products, on_delete=models.CASCADE)
    added_at = models.DateTimeField(auto_now_add=True)